/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*******************************************************************
 * ApplicationInterface.c 
 * target: Pushpin TOF
 *
 * Last modified 04MAR2004 by lifton.
 *
 * This is the file you should edit if you wish to interface a 
 * piece of application code with all aspects of Bertha.  
 *******************************************************************/
#include <c8051F000.h>
#include <PushpinHardwareV3.h>
#include <Bertha.h>
#include <BerthaFunctionPrototypes.h>
// #include <CommTest.h>

/*
 * This function is called once during initialization.
 */
void applicationInitialization(void) {
  initializeTOFModule();
  // initializeCommTest();
  // initializeNeighborTest();
}

/*
 * This function is called once for every pass through the main 
 * while loop in BerthaOS.c.  There is no guarantee of how much 
 * time has gone by between calls, but a best-effort is made to 
 * keep it consistent and short.  If need be, application code 
 * can determine the actual amount of time that has passed by 
 * using the real-time clock provided through BerthaTiming.c.
 */ 
void applicationLoop(void) {
  TOFRunLoop();  
  // TOFSynTest();
  // commTestLoop();
  // neighborTestLoop();
}


/*
 * This function is called whenever any data-carrying packet is received
 * (i.e., SYN and BROADCAST packets, but not ACK or NAK packets).  Note 
 * that if a SYN packet is received, then it will be acknowledged with an ACK
 * packet sent by the AcknowledgedDataLink.c layer.  Thus, any application code 
 * should expect the transmit packet queue to be full upon receipt of a packet.
 * That is, the queue will be full until the acknowledgement is sent.  In 
 * practical terms, this means that application code should not expect to be 
 * able to queue a packet upon receipt of a packet and should provide its own
 * message queueing facilities which build on those of the queuePacket funtion
 * in AcknowledgedDataLink.c.
 */
void applicationPacketReceivedCallback(Packet* packetPtr) {
  receiveTOFmessage(packetPtr);
  // receiveCommTestMessage(packetPtr);
  // receiveNeighborTestMessage(packetPtr);
}

/*
 * This function is called whenever either a BROADCAST or SYN packet has 
 * been successfully transmitted.  Thus, for BROADCAST packets, this function 
 * is called immediately after transmission, but for SYN packets this function
 * is called only after the appropriate ACK has been received.  If for some 
 * reason an ACK isn't received, then the applicationPacketNotSentCallback 
 * function will be called instead.
 */
void applicationPacketSentCallback(void) {
  // commTestMessageSent();
}

/*
 * This function is called whenever a SYN packet is not acknowledged with 
 * an ACK packet.  See the description of applicationPacketSentCallback for
 * more/related information.  WARNING: THIS FUNCTION DOES NOT SCALE TO MORE
 * THAN ONE APPLICATION RUNNING AT THE SAME TIME.
 */
void applicationPacketNotSentCallback(void) {
  // commTestMessageNotSent();
}
