/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*******************************************************************************
 * BerthaFunctionPrototypes.h
 * target: PushpinV3
 *
 * Last modified 03OCT2002 by lifton.
 *
 * This file contains all function prototypes needed to compile the Bertha 
 * operating system.  Function prototypes are listed in alphabetical order 
 * by function name and grouped according to the file they are defined in.
 *******************************************************************************/

/* BerthaOS.c */
//unsigned int getBerthaVersion(void);

/* BerthaFunctions.c -- Functions available only to Bertha. */
void configurePins(void);
void disableWatchdogTimer(void);
unsigned char enableADCChannel(unsigned char);
void enableExternalClock(void);
void initializeHardware(void);
void flashLED(unsigned int, unsigned int);
void generateRandomSeed(void);
void generateRandomNeighborhoodID(void);
void copyXdataToFlash(unsigned char code *, unsigned char xdata *, unsigned int);
void saveOSState(OSState xdata *);
void delay(unsigned int);


/* BerthaFunctions.c -- Miscellaneous functions for general use. */
unsigned int getADCValue(unsigned char);
unsigned int generateRandomNumberFromADC(void);

/* CommDataLink.c -- Functions to handle low level communication. */
void configureIRCommModule(void);
unsigned char sendQueuedPacket(void);
// void disableCommunication(void);  be very careful... see timer2Interrupt in the days of yore
void enableCommunication(void);

/* AcknowledgeDataLink.c */
void initializeAcknowledgedDataLink(void);
unsigned char queuePacket(unsigned char toAddress,	      // Intended recipient's neighborhood ID.
			  unsigned char packetType,	      // Classification of this packet.
			  unsigned int contentSize,	      // The number of bytes of content contained in this packet.
			  unsigned char xdata * contentPtr); // Location of the content.
unsigned char getNeighborID(unsigned char neighborIndex);
unsigned char getNumOfNeighbors(void);


/* BerthaTiming.c -- Management of real-time clock and timers. */
void startRealTimeClock(void);
unsigned long getTime(void);
void setTime(unsigned long);


/* ApplicationInterface.c * -- Functions to interface with Pushpin Applications */
void applicationInitialization(void);
void applicationLoop(void);
void applicationPacketReceivedCallback(Packet *);
void applicationPacketSentCallback(void);
void applicationPacketNotSentCallback(void);

/* TOFModule * -- Configuration used for Time Of Flight expansion module */
void TOFRunLoop(void);
void initializeTOFModule(void);
void receiveTOFmessage(Packet *);
void setRGBLEDIntensity(unsigned char, unsigned char);
void clearRGBLEDDisplay(void);

/* codecs.c -- Lookup tables and some associated functions. */
unsigned char getFlashBlockCRC8(unsigned char code*, unsigned int);

/* rand.c -- Pseudo-random number gnerator */
unsigned int rand(void);
unsigned int rand_r(unsigned int *);
void srand(unsigned int);

/* NeighborhoodTest.c */
void neighborTestLoop(void);
void initializeNeighborTest(void);
void receiveNeighborTestMessage(Packet* packetPtr);

