/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*
 * BerthaOS.c 
 * target: Pushpin TOF
 *
 * Last modified 04MAR2004 by lifton.
 *
 * This is Bertha, the operating system for Pushpins.
 *
 *  Thing that should come to pass but have not yet:
 *    - packet received clock check for random bits.
 *
 *******************************************************************/

#include <c8051F000.h>
#include <PushpinHardwareV3.h>
#include <Bertha.h>
#include <BerthaFunctionPrototypes.h>
#include <BerthaInterruptPrototypes.h>
#include <BerthaGlobals.h>

void osEntryPoint(void);

#define NEIGHBORHOOD_ATTEMPTS 3

const code at MiniPageAddress OSState osState = 0x00;

void main(void) {
  initializeHardware();
  osEntryPoint();
}

void lastInterrupt(void) interrupt 21 {
}

void osEntryPoint(void) {

  unsigned char broadcastCountdown = 0;
  unsigned char i;

  /* 
   * Initialization. 
   */
//  initializeHardware();
  generateRandomSeed();
  enableGlobalInterrupts();
  startRealTimeClock();
  configureIRCommModule();
  initializeAcknowledgedDataLink();
  applicationInitialization();
  enableCommunication();
  
  /*
   * Indicate on-board initialization complete.
   */
  flashLED(10,0xFFFF);

  /*
   * Send a broadcast out at a random time after start up to build up neighborhood.
   */
  for (i=0 ; i < NEIGHBORHOOD_ATTEMPTS ; i++) {
    while (broadcastCountdown++ != NeighborhoodID) {
      delay(0x0fff);
    }
    queuePacket(GLOBALADDRESS, BROADCAST, 0, 0);
  }

  /* Control loop. */
  while (1) {
    /*
     * Make sure all packets get sent.
     */
    sendQueuedPacket();

    /*
     * Hook for application code.
     */
    applicationLoop();
    
  }
}
