/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*******************************************************************
 * ApplicationInterface.c 
 * target: Pushpin TOF
 *
 * Last modified 04MAR2004 by lifton.
 *
 * This is the file you should edit if you wish to interface a 
 * piece of application code with all aspects of Bertha.  
 *******************************************************************/
#include <c8051F000.h>
#include <PushpinHardwareV3.h>
#include <Bertha.h>
#include <BerthaFunctionPrototypes.h>
#include <CommTest.h>

#define SEND_PACKET_TIMER_RELOAD 250000
#define CONTENT_SIZE 4
unsigned long sendPacketTimer;
bit shouldFlash;
unsigned char xdata content[CONTENT_SIZE];

 #define RECEIVE_TEST 1

void initializeCommTest(void) {
  unsigned char i;
  for (i=0; i<CONTENT_SIZE; i++) {
    content[i] = 0xc0 + i;
  }
  sendPacketTimer = 0;
  shouldFlash = FALSE;
}


void commTestLoop(void) {
  unsigned char neighborIndex;

  #ifndef RECEIVE_TEST
  if (sendPacketTimer++ >= SEND_PACKET_TIMER_RELOAD) {
    sendPacketTimer = 0;
    if (getNumOfNeighbors() > 0) {
      for (neighborIndex=0; neighborIndex<getNumOfNeighbors(); neighborIndex++) {
        if (getNeighborID(neighborIndex) != GLOBALADDRESS) {
          break;
        }
      }
      queuePacket(getNeighborID(neighborIndex),	      // Intended recipient's neighborhood ID.
  		            SYN,	          // Classification of this packet.
  		            CONTENT_SIZE,	        // The number of bytes of content contained in this packet.
    	            content);             // Location of the content.
    }
  }
  #endif

  if (shouldFlash) {
    shouldFlash = FALSE;
    flashLED(1,0xffff);
  }
}

void receiveCommTestMessage(Packet* packetPtr) {
  #ifdef RECEIVE_TEST
  unsigned char i;
  if (packetPtr->fromAddress == IDEADDRESS) {
    shouldFlash = TRUE;
    queuePacket(IDEADDRESS, 
                BROADCAST, 
                CONTENT_SIZE, 
                content);
  }
  else if (packetPtr->contentSize == CONTENT_SIZE) {
    shouldFlash = TRUE;
    for (i=0; i<CONTENT_SIZE; i++) {
      if (*((packetPtr->contentPtr) + i) != content[i]) {
        shouldFlash = FALSE;
        break;
      }
    }
  }
  #endif
}


void commTestMessageSent(void) {
  #ifndef RECEIVE_TEST
  shouldFlash = TRUE;
  #endif
}

void commTestMessageNotSent(void) {

}

