/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*******************************************************************************
 * DataLink.h
 * target hardware: Pushpin Time Of Flight
 * target compiler: SDCC
 *
 * Last modified 01MAR2004 by lifton & broxton.
 *
 * This header file contains data structures, macros, constants 
 * and function prototypes related to the data link layer of the 
 * Pushpin communication system.
 *******************************************************************************/

#define IR_FRAME_START_BYTE 0x50

/*
 * Define this if you want to use a randomly generated neighborhood ID.
 * Otherwise, we use the first byte of the random seed in the osState 
 * (code location 0x8000).
 */
// #define USE_RANDOM_NEIGHBORHOOD_ID

/*
 * Function Prototypes
 */
unsigned char queueBasicPacket(unsigned char toAddress,	          // Intended recipient's neighborhood ID.
			       unsigned char packetType,	  // Classification of this packet.
			       unsigned char sequenceNumber,      // Counter for the number of packets sender has successfully sent.
			       unsigned int contentSize,	  // The number of bytes of content contained in this packet.
			       unsigned char xdata * contentPtr); // Location of the content.


void packetSentCallback(Packet xdata *);
void packetReceivedCallback(Packet xdata *);
void headerCRCErrorCallback(void);
void contentCRCErrorCallback(Packet xdata *);
