/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*******************************************************************
 * ApplicationInterface.c 
 * target: Pushpin TOF
 *
 * Last modified 04MAR2004 by lifton.
 *
 * This is the file you should edit if you wish to interface a 
 * piece of application code with all aspects of Bertha.  
 *******************************************************************/
#include <c8051F000.h>
#include <PushpinHardwareV3.h>
#include <Bertha.h>
#include <BerthaFunctionPrototypes.h>
#include <BerthaGlobals.h>

#define SEND_PACKET_TIMER_RELOAD 250000
#define CONTENT_SIZE 4
unsigned long sendPacketTimer;
bit shouldFlash, isTesting;
unsigned char xdata content[CONTENT_SIZE];

void initializeNeighborTest(void) {
  unsigned char i;
  initializeTOFModule();
  for (i=0; i<CONTENT_SIZE; i++) {
    content[i] = 0xc0 + i;
  }
  sendPacketTimer = 0;
  shouldFlash = FALSE;
  isTesting = FALSE;
}


void flashRGBLED(unsigned char color, unsigned char times, unsigned int interval) {
  clearRGBLEDDisplay();
  while(times--) {
		setRGBLEDIntensity(color, 0x00);
		delay(interval);
		setRGBLEDIntensity(color, 0xff);
		delay(interval);
	}
}

void neighborTestLoop(void) {
  if (isTesting) {
    delay(0xffff);
    delay(0xffff);
    flashRGBLED(RGB_BLUE, 1,30000);
    queuePacket(GLOBALADDRESS,	      // Intended recipient's neighborhood ID.
    		        BROADCAST,	          // Classification of this packet.
    		        CONTENT_SIZE,	        // The number of bytes of content contained in this packet.
      	        content);             // Location of the content.
  }
  if (shouldFlash) {
    shouldFlash = FALSE;
    flashRGBLED(RGB_RED, 1,30000);
  }
}

void receiveNeighborTestMessage(Packet* packetPtr) {
  unsigned char i;
  if (packetPtr->fromAddress == IDEADDRESS) {
    if (*(packetPtr->contentPtr) == NeighborhoodID) {
      isTesting = TRUE;
    }
    else {
      isTesting = FALSE;
    }
  }
  else {
    shouldFlash = TRUE;
  }
}

