/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/**************************************************************************
 * TOFInput.c
 * target: PushpinTOF
 *
 * Last modified 14JUN2004 by mbroxton.
 *
 * Functions pertaining to acquiring data from analog sensors on the TOF module.
 * Some of this code is adapted from the Tribble code tree.
 ***************************************************************************/

#include <c8051F000.h>
#include <PushpinHardwareV3.h>
#include <Bertha.h>
#include <BerthaFunctionPrototypes.h>
#include <BerthaGlobals.h>
#include <TOF.h>


void initializeTOFInput(void) {
	/*
	 * Enable ADC and start it going.
	 */
	REF0CN |= 0x03;		// Enable VREF and ADC/DAC bias.
	AMX0CF = 0x00;		// Single-ended inputs (not differential).
	ADC0CF &= ~(0x07);	// Gain 1.
	ADC0CF |= 0xE0;		// Conversion clock to system clock / 16.
	ADLJST = 1;			// Left justification.
	ADSTM0 = 0;			// ADC conversion begins with a write to ADBUSY 
	ADSTM1 = 0;			
	ADCINT = 0;			// Clear ADC End of Conversion interrupt flag.
	ADCEN = 1;			// Enable ADC.
}


/*
 * Get a single reading from the ADC.  This routine is somewhat 
 * slow, since it blocks until the data conversion is complete, so it should 
 * not be used for harvesting data continually. 
 */
unsigned char getSensorReading(unsigned char sensor) {
  AMX0SL = sensor;           // Select the appropriate sensor an the AMUX.
  ADBUSY = 1;                // Start the ADC conversion.
  while (ADBUSY == 1);       // Do nothing until the conversion is complete.
  return ADC0H;
}
